@@ -21,13 +21,20 @@ else if (file_exists('./plugins/compatibility/functions.php'))
 
 
 
+if (compatibility_check_sm_version(1, 3))
+   include_once (SM_PATH . 'plugins/lockout/data/config.php');
+else
+   include_once ('../plugins/lockout/data/config.php');
+
+
+
 // parses a table that lists domains and/or users that are
 // to be locked out and not allowed to log in
 //
 function check_lockout_do()
 {
 
-   global $username, $at;
+   global $username, $at, $reverseLockout;
 
 
    $user = $username;
@@ -86,6 +93,8 @@ function check_lockout_do()
                           strtoupper($matches[1])) . '$/', strtoupper($usersDomain)))
             {
                fclose($LOCKOUTTABLE);
+               if ($reverseLockout)
+                  return;
                redirect($matches[2]);
             }
 
@@ -104,6 +113,8 @@ function check_lockout_do()
                           strtoupper($matches[1])) . '$/', strtoupper($host)))
             {
                fclose($LOCKOUTTABLE);
+               if ($reverseLockout)
+                  return;
                redirect($matches[2]);
             }
 
@@ -122,6 +133,8 @@ function check_lockout_do()
                           strtoupper($matches[1])) . '$/', strtoupper($user)))
             {
                fclose($LOCKOUTTABLE);
+               if ($reverseLockout)
+                  return;
                redirect($matches[2]);
             }
 
@@ -131,6 +144,13 @@ function check_lockout_do()
 
       fclose($LOCKOUTTABLE);
 
+
+      // if we are reversing functionality, lockout anyone 
+      // not found in the lockout file
+      //
+      if ($reverseLockout)
+         redirect($reverseLockout);
+
    }
 
 }
